package com.mihai.masina;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.util.Log;
import android.widget.ImageView;

import java.io.IOException;
import java.util.UUID;

/**
 * Created by MihaiBranescu on 5/23/2016.
 */
public class ConnectThread  extends Thread {
    static final UUID BT_UUID = UUID.fromString("00001101-0000-1000-8000-00805F9B34FB");
    private final BluetoothSocket mmSocket;
    private final BluetoothDevice mmDevice;
    private BluetoothAdapter mBluetoothAdapter;
    private MainActivity mMainActivity;

    public ConnectThread(BluetoothDevice device, MainActivity mainActivity) {
        // Use a temporary object that is later assigned to mmSocket,
        // because mmSocket is final
        BluetoothSocket tmp = null;
        mmDevice = device;
        mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();

        // Get a BluetoothSocket to connect with the given BluetoothDevice
        try {
            // MY_UUID is the app's UUID string, also used by the server code
            tmp = device.createRfcommSocketToServiceRecord(BT_UUID);
        } catch (IOException e) { }
        mmSocket = tmp;

        mMainActivity = mainActivity;
    }

    public void run() {
        // Cancel discovery because it will slow down the connection
        mBluetoothAdapter.cancelDiscovery();

        try {
            // Connect the device through the socket. This will block
            // until it succeeds or throws an exception
            mmSocket.connect();
        } catch (IOException connectException) {
            // Unable to connect; close the socket and get out
            try {
                mmSocket.close();
            } catch (IOException closeException) {

                Log.e("CONNECT", "ERROR boss");
            }
            return;
        }

        Log.e("CONNECT", "connected boss");

        mMainActivity.setSocket(mmSocket);

        // Set status image.
        final ImageView img = (ImageView) mMainActivity.findViewById(R.id.status);
        if (img != null) {
            img.post(new Runnable() {
                public void run() {
                    img.setImageResource(R.drawable.ok2);
                }
            });
        }

        // Do work to manage the connection (in a separate thread)
        (new ConnectedThread(mmSocket, mMainActivity)).start();
    }

    /** Will cancel an in-progress connection, and close the socket */
    public void cancel() {
        try {
            mmSocket.close();
        } catch (IOException e) { }
    }
}