package com.mihai.masina;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.view.MotionEvent;
import android.view.View;
import android.view.Window;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;


public class MainActivity extends AppCompatActivity {
    BluetoothAdapter mBluetoothAdapter;
    static final String MAC = "20:15:03:17:14:89";
    static boolean hasStarted = false;
    BluetoothSocket mSocket;
    ConnectedThread mConnectedThread;
    boolean mIsConnected;
    public ImageView statusImg;

    @Override
    protected void onResume() {
        super.onResume();
        if(hasStarted)
            statusImg.performClick();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        this.requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.activity_main);

        mSocket = null;
        mIsConnected = false;

        mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();

        if (!mBluetoothAdapter.isEnabled()) {
            // If Bluetooth is disabled.
            Toast.makeText(this,"Bluetooth is disabled on the Android device.", Toast.LENGTH_SHORT).show();
        }

        statusImg = (ImageView)findViewById(R.id.status);
        if (statusImg != null) {
            statusImg.setImageResource(R.drawable.nok);


            statusImg.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (mIsConnected) {
                        hasStarted= true;
                        v.setVisibility(View.GONE);
                        TextView text = (TextView) findViewById(R.id.statusText);
                        if (text != null) {
                            text.setVisibility(View.GONE);
                        }
                        RelativeLayout controls = (RelativeLayout) findViewById(R.id.controls);
                        if (controls != null) {
                            controls.setVisibility(View.VISIBLE);
                        }
                    }
                }
            });
        }

        // Connect to the HC-06 module
        BluetoothDevice device;
        device = mBluetoothAdapter.getRemoteDevice(MAC);

        if (device == null) {
            Toast.makeText(this, "Couldn't find HC-06 module.", Toast.LENGTH_LONG).show();
            return;
        }

        (new ConnectThread(device, MainActivity.this)).start();

        Button button;

        //while (!mIsConnected);

        // Set listener for up_button
        button = (Button) this.findViewById(R.id.up_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("w".getBytes());
                        return true;

                    }
                    return false;
                }
            });
        }
        // Set listener for down_button
        button = (Button) this.findViewById(R.id.down_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("x".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }
        // Set listener for left_button
        button = (Button) this.findViewById(R.id.left_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("a".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }
        // Set listener for right_button
        button = (Button) this.findViewById(R.id.right_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("d".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }
        // Set listener for up_left_button
        button = (Button) this.findViewById(R.id.up_left_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("q".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }
        // Set listener for up_right_button
        button = (Button) this.findViewById(R.id.up_right_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("e".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }
        // Set listener for down_left_button
        button = (Button) this.findViewById(R.id.down_left_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("z".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }
        // Set listener for down_right_button
        button = (Button) this.findViewById(R.id.down_right_button);
        if (button != null) {
            button.setOnTouchListener(new View.OnTouchListener() {
                @Override
                public boolean onTouch(View v, MotionEvent event) {
                    v.onTouchEvent(event);
                    if (event.getAction() == MotionEvent.ACTION_UP) {
                        mConnectedThread.write("0".getBytes());
                        return true;
                    }
                    if (event.getAction() == MotionEvent.ACTION_DOWN) {
                        mConnectedThread.write("c".getBytes());
                        return true;
                    }
                    return false;
                }
            });
        }

        button = (Button) this.findViewById(R.id.stop);
        if (button != null) {
            button.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    mConnectedThread.write("0".getBytes());
                }
            });
        }
    }


    void setSocket(BluetoothSocket sock) {
        mSocket = sock;
    }

    void setIsConnected(boolean val) {
        mIsConnected = val;
    }
}